@@ -2,11 +2,11 @@
 # See the LICENSE file for the full license.
 
 name = "TweetPony"
-version = "1.2.4"
+version = "1.2.5"
 description = "A Twitter library for Python"
 license = "AGPLv3"
 author = "Julian Metzler"
 author_email = "contact@mezgrman.de"
-dependencies = ['requests']
+requires = ['requests<=1.2.0']
 url = "https://github.com/Mezgrman/TweetPony"
 keywords = "twitter library api wrapper pony"
